package
Version:
v0.2.1
Opens a new window with list of versions in this module.
Published: Dec 15, 2025
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Config holds the watcher configuration
type FileEvent struct {
Path string
}
FileEvent represents a file change event
Watcher monitors filesystem changes
New creates a new watcher instance
Events returns the channel of file events
Start begins watching for file changes (no debouncing - handled in main loop)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.