Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PromptAndSaveProvider ¶ added in v0.2.2
func PromptAndSaveProvider() error
PromptAndSaveProvider prompts the user to select a provider and saves it to global config
Types ¶
type Config ¶
type Config struct {
Watch []string `yaml:"watch"`
Ignore []string `yaml:"ignore"`
Logs LogsConfig `yaml:"logs"`
LLM LLMConfig `yaml:"llm"`
}
Config holds the complete application configuration
func (*Config) GetDebounceDuration ¶
GetDebounceDuration returns debounce duration for file changes
func (*Config) SaveGlobal ¶ added in v0.2.2
SaveGlobal saves the config to the global config file
type LLMConfig ¶
type LLMConfig struct {
Provider string `yaml:"provider"`
Model string `yaml:"model"`
APIKey string `yaml:"api_key"`
SystemPrompt string `yaml:"system_prompt"`
}
LLMConfig holds LLM provider configuration
type LogsConfig ¶
LogsConfig holds log scraping configuration
Click to show internal directories.
Click to hide internal directories.