Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetChangedFiles ¶ added in v0.1.5
GetChangedFiles returns a list of all changed files (staged and unstaged)
Types ¶
type Diff ¶
Diff represents a git diff for a specific file
func GetDiff ¶
GetDiff returns the git diff for the specified files or all changes if no files specified
func GetStagedDiff ¶ added in v0.2.0
GetStagedDiff returns only the staged diff for specified files
type StagedState ¶ added in v0.2.0
type StagedState struct {
StagedFiles []string
Hash string // Hash of the staged state for change detection
}
StagedState represents the current state of staged changes
func GetStagedState ¶ added in v0.2.0
func GetStagedState() (*StagedState, error)
GetStagedState returns the current staged state with hash for change detection
Click to show internal directories.
Click to hide internal directories.