git

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Diff

type Diff struct {
	FilePath string
	Content  string
}

Diff represents a git diff for a specific file

func GetDiff

func GetDiff(files ...string) ([]Diff, error)

GetDiff returns the git diff for the specified files or all changes if no files specified

Jump to