ui

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunLoadingAnimation

func RunLoadingAnimation(text string) (*tea.Program, func())

RunLoadingAnimation starts a loading animation and returns a function to stop it

Types

type LoadingModel

type LoadingModel struct {
	// contains filtered or unexported fields
}

LoadingModel represents a loading animation model

func NewLoading

func NewLoading(text string) *LoadingModel

NewLoading creates a new loading animation model

func (*LoadingModel) Init

func (m *LoadingModel) Init() tea.Cmd

Init implements tea.Model

func (*LoadingModel) Update

func (m *LoadingModel) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update implements tea.Model

func (*LoadingModel) View

func (m *LoadingModel) View() string

View implements tea.Model

type LoadingMsg

type LoadingMsg struct{}

LoadingMsg is a message to update the loading animation

type MarkdownRenderer

type MarkdownRenderer struct {
	// contains filtered or unexported fields
}

MarkdownRenderer handles markdown rendering with glamour

func NewMarkdownRenderer

func NewMarkdownRenderer() (*MarkdownRenderer, error)

NewMarkdownRenderer creates a new markdown renderer

func (*MarkdownRenderer) Render

func (r *MarkdownRenderer) Render(markdown string) (string, error)

Render renders markdown text

func (*MarkdownRenderer) RenderResponse

func (r *MarkdownRenderer) RenderResponse(content string) string

RenderResponse renders an LLM response with markdown

type SpinnerModel

type SpinnerModel struct {
	// contains filtered or unexported fields
}

SpinnerModel represents a compact spinner model

func NewSpinner

func NewSpinner(text string) *SpinnerModel

NewSpinner creates a new spinner model

func (*SpinnerModel) Tick

func (m *SpinnerModel) Tick() string

Tick updates the spinner

Jump to